@@ -5,6 +5,7 @@
 #include <QMaemo5EditBar>
 #include <QtGui>
 #include "xml.h"
+#include "qmaemo5rotator.h"
 
 class ExportWindow : public QMainWindow
 {
@@ -12,6 +13,7 @@ class ExportWindow : public QMainWindow
 public:
     explicit ExportWindow(QWidget *parent = 0);
     void loadExercises(QString grp);
+    QMaemo5Rotator *exwRot;
 signals:
 
 private:
