@@ -5,6 +5,7 @@
 #include "xml.h"
 #include <QMaemo5ValueButton>
 #include <QMaemo5ListPickSelector>
+#include "qmaemo5rotator.h"
 
 class FoodDialog : public QDialog
 {
@@ -13,7 +14,7 @@ class FoodDialog : public QDialog
 public:
     explicit FoodDialog(QWidget *parent = 0);
     void load();
-
+    QMaemo5Rotator *fdRot;
 private:
     XML *xml;
 
