@@ -8,19 +8,6 @@ FoodWindow::FoodWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
     xml = new XML();
-    fd = new FoodDialog(this);
-    fd->hide();
-
-    sw = new SettingsWindow(this);
-    sw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
 
     QWidget *widget = new QWidget();
 
@@ -42,33 +29,50 @@ FoodWindow::FoodWindow(QWidget *parent) :
 
 }
 
+void FoodWindow::sendClosed()
+{
+    emit closed();
+}
+
 void FoodWindow::changeEvent(QEvent *event)
 {
     load();
     this->update();
 }
 
+void FoodWindow::showNewIngredient()
+{
+    niw = new NewIngredientWindow(this);
+    niw->load();
+    niw->show();
+}
+
 void FoodWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
-
 void FoodWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void FoodWindow::showNewExercise()
 {
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
 void FoodWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
@@ -130,13 +134,8 @@ void FoodWindow::load()
 
 void FoodWindow::showDialog()
 {
+    fd = new FoodDialog(this);
     fd->load();
     fd->show();
 }
 
-void FoodWindow::showNewIngredient()
-{
-    niw->load();
-    niw->show();
-}
-
