@@ -7,22 +7,6 @@ ListWindow::ListWindow(QWidget *parent) :
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    iw = new InfoWindow(this);
-    iw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    imw = new InfoMotionWindow(this);
-    imw->hide();
-    sw = new SettingsWindow(this);
-    sw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-    ew = new ExportWindow(this);
-    ew->hide();
     xml = new XML();
 
     model = new QStandardItemModel(this);
@@ -42,6 +26,16 @@ ListWindow::ListWindow(QWidget *parent) :
 
 }
 
+void ListWindow::sendLandscape()
+{
+    emit landscape();
+}
+
+void ListWindow::sendClosed()
+{
+    emit closed();
+}
+
 void ListWindow::changeEvent(QEvent *event)
 {
     if(event->type() == QEvent::ActivationChange)
@@ -74,48 +68,67 @@ void ListWindow::loadExercises(QString grp)
     model->sort(0);
 }
 
-void ListWindow::showNewIngredient()
-{
-    niw->load();
-    niw->show();
-}
 void ListWindow::showInfo(QModelIndex index)
 {
     setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
     if(index.data().toString() == "No exercises")
         return;
+
+
     if(group !=  "Cardio")
     {
+        iw = new InfoWindow(this);
+        connect(iw,SIGNAL(closed()),this,SLOT(sendClosed()));
+        connect(iw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
+
         iw->loadExercise(index.data().toString());
         iw->show();
     }
     else
     {
+        imw = new InfoMotionWindow(this);
+        connect(imw,SIGNAL(closed()),this,SLOT(sendClosed()));
+        connect(imw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
         imw->loadMotionExercise(index.data().toString());
         imw->show();
     }
 }
 
-void ListWindow::showSettings()
+void ListWindow::showNewIngredient()
 {
-    sw->load();
-    sw->show();
+    niw = new NewIngredientWindow(this);
+    niw->load();
+    niw->show();
 }
 
 void ListWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
+void ListWindow::showSettings()
+{
+    sw = new SettingsWindow(this);
+    sw->load();
+    sw->show();
+}
+
 void ListWindow::showNewExercise()
 {
+    nw = new NewExerciseWindow(this);
+
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
+
     nw->load();
     nw->show();
 }
 
 void ListWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
@@ -196,6 +209,7 @@ void ListWindow::editItem()
 
 void ListWindow::showExport()
 {
+    ew = new ExportWindow(this);
     ew->loadExercises(group);
     ew->show();
 }
