@@ -20,8 +20,12 @@ public:
     void loadDate(QString date);
 
 signals:
+    void closed();
+    void landscape();
 
 public slots:
+    void sendClosed();
+    void sendLandscape();
 
 private:
     XML *xml;
