@@ -11,16 +11,6 @@ NewIngredientWindow::NewIngredientWindow(QWidget *parent)
 
     QVBoxLayout *vLayout = new QVBoxLayout;
 
-    modelCalories = new QStandardItemModel(this);
-    for (int i = 1; i < 500; i++)
-        modelCalories->appendRow(new QStandardItem(tr("%1").arg(i)));
-
-    btnCalories = new QMaemo5ValueButton("Calories / 100g");
-    btnCalories->setValueLayout(QMaemo5ValueButton::ValueUnderText);
-    selectorCalories = new QMaemo5ListPickSelector();
-    selectorCalories->setModel(modelCalories);
-    btnCalories->setPickSelector(selectorCalories);
-
     modelProtein = new QStandardItemModel(this);
     for (int i = 1; i < 100; i++)
         modelProtein->appendRow(new QStandardItem(tr("%1").arg(i)));
@@ -66,7 +56,6 @@ NewIngredientWindow::NewIngredientWindow(QWidget *parent)
 
     vLayout->addWidget(txtName);
     vLayout->addWidget(btnType);
-    vLayout->addWidget(btnCalories);
     vLayout->addWidget(btnProtein);
     vLayout->addWidget(btnCarbohydrate);
     vLayout->addWidget(btnFat);
@@ -82,14 +71,15 @@ NewIngredientWindow::NewIngredientWindow(QWidget *parent)
 
 void NewIngredientWindow::load()
 {
-    btnCalories->setFocus();
-    btnCalories->setValueText("");
+    btnType->setFocus();
     btnType->setValueText("");
     txtName->setText("");
 }
 
 void NewIngredientWindow::save()
 {
+    int kcal = 0;
+    QString calories;
     if(txtName->text() == "")
     {
         QMaemo5InformationBox::information(this, "You must fill in name.", QMaemo5InformationBox::DefaultTimeout);
@@ -100,11 +90,6 @@ void NewIngredientWindow::save()
         QMaemo5InformationBox::information(this, "You must choose a type.", QMaemo5InformationBox::DefaultTimeout);
         return;
     }
-    else if(btnCalories->valueText() == "")
-    {
-        QMaemo5InformationBox::information(this, "You must choose an amount of calories.", QMaemo5InformationBox::DefaultTimeout);
-        return;
-    }
     else if(btnProtein->valueText() == "")
     {
         QMaemo5InformationBox::information(this, "You must choose an amount of protein.", QMaemo5InformationBox::DefaultTimeout);
@@ -121,7 +106,13 @@ void NewIngredientWindow::save()
         return;
     }
 
-    xml->saveFood(txtName->text(), btnType->valueText(), btnCalories->valueText(),
+    kcal = btnProtein->valueText().toInt() * 4;
+    kcal += btnCarbohydrate->valueText().toInt() * 4;
+    kcal += btnFat->valueText().toInt() * 9;
+
+    calories.setNum(kcal);
+
+    xml->saveFood(txtName->text(), btnType->valueText(), calories,
                   btnProtein->valueText(), btnCarbohydrate->valueText(), btnFat->valueText());
     this->hide();
 }
