@@ -7,19 +7,6 @@ WeightWindow::WeightWindow(QWidget *parent) :
     //setAttribute(Qt::WA_Maemo5LandscapeOrientation);
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    lw = new ListWindow(this);
-    lw->hide();
-    sw = new SettingsWindow(this);
-    sw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-
     QWidget *widget = new QWidget;
     setCentralWidget(widget);
 
@@ -53,68 +40,104 @@ WeightWindow::WeightWindow(QWidget *parent) :
     resize(480,720);
 }
 
+void WeightWindow::sendClosed()
+{
+    emit closed();
+}
+
+void WeightWindow::sendLandscape()
+{
+    emit landscape();
+}
+
 void WeightWindow::showNewIngredient()
 {
+    niw = new NewIngredientWindow(this);
     niw->load();
     niw->show();
 }
 
-void WeightWindow::showArmsList()
-{
-    lw->loadExercises("Arms");
-    lw->show();
-}
-void WeightWindow::showBackList()
-{
-    lw->loadExercises("Back");
-    lw->show();
-}
-void WeightWindow::showChestList()
-{
-    lw->loadExercises("Chest");
-    lw->show();
-}
-void WeightWindow::showLegsList()
-{
-    lw->loadExercises("Legs");
-    lw->show();
-}
-void WeightWindow::showShoulderList()
-{
-    lw->loadExercises("Shoulder");
-    lw->show();
-}
-void WeightWindow::showStomachList()
-{
-    lw->loadExercises("Stomach");
-    lw->show();
-}
-
 void WeightWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
 void WeightWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void WeightWindow::showNewExercise()
 {
-
-
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
 void WeightWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
+void WeightWindow::showArmsList()
+{
+    lw = new ListWindow(this);
+    connect(lw,SIGNAL(closed()),this,SLOT(sendClosed()));
+    connect(lw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
+    lw->loadExercises("Arms");
+    lw->show();
+}
+void WeightWindow::showBackList()
+{
+    lw = new ListWindow(this);
+
+    connect(lw,SIGNAL(closed()),this,SLOT(sendClosed()));
+    connect(lw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
+    lw->loadExercises("Back");
+    lw->show();
+}
+void WeightWindow::showChestList()
+{
+    lw = new ListWindow(this);
+    connect(lw, SIGNAL(landscape()),this,SLOT(sendLandscape()));
+    connect(lw,SIGNAL(closed()),this, SLOT(sendClosed()));
+    lw->loadExercises("Chest");
+    lw->show();
+}
+void WeightWindow::showLegsList()
+{
+    lw = new ListWindow(this);
+    connect(lw, SIGNAL(landscape()),this,SLOT(sendLandscape()));
+    connect(lw,SIGNAL(closed()),this, SLOT(sendClosed()));
+    lw->loadExercises("Legs");
+    lw->show();
+}
+void WeightWindow::showShoulderList()
+{
+    lw = new ListWindow(this);
+    connect(lw, SIGNAL(landscape()),this,SLOT(sendLandscape()));
+    connect(lw,SIGNAL(closed()),this, SLOT(sendClosed()));
+    lw->loadExercises("Shoulder");
+    lw->show();
+}
+void WeightWindow::showStomachList()
+{
+    lw = new ListWindow(this);
+    connect(lw, SIGNAL(landscape()),this,SLOT(sendLandscape()));
+    connect(lw,SIGNAL(closed()),this, SLOT(sendClosed()));
+    lw->loadExercises("Stomach");
+    lw->show();
+}
+
+
+
 void WeightWindow::createMenu()
 {
     QMenu *menu;
